@@ -7,6 +7,7 @@ class Data::DPath::Path {
         use Data::Dumper;
         use Data::DPath::Step;
         use Data::DPath::Point;
+        use Data::DPath::Context;
         use Text::Balanced qw (
                                       extract_delimited
                                       extract_bracketed
@@ -76,9 +77,10 @@ class Data::DPath::Path {
                         }
 
                         given ($plain_part) {
-                                when ('*')  { $kind ||= 'ANYSTEP'  }
-                                when ('..') { $kind ||= 'PARENT'   }
                                 when ('')   { $kind ||= 'ANYWHERE' }
+                                when ('*')  { $kind ||= 'ANYSTEP'  }
+                                when ('.')  { $kind ||= 'NOSTEP'   }
+                                when ('..') { $kind ||= 'PARENT'   }
                                 default     { $kind ||= 'KEY'      }
                         }
                         push @steps, new Data::DPath::Step( part   => $plain_part,
